@@ -180,36 +180,36 @@ sub new
 	close DICT;
     }
 
-	if(defined $compoundfile) {
-
-    #replace the compound words in the definition
-    open(LST, "$compoundfile") or die ("Error: cannot open file $compoundfile for input.\n");
-
-    # read the compound txt and put them in the hash array. 
-    while (my $line = <LST>)
-    {
-        chomp($line);
-        my $lower_case = lc($line);
-        my @string = split('_', $lower_case);
-        my $head = shift(@string);
-
-        my $rest = join (' ', @string);
-        push (@{$complist{$head}}, $rest);
+    if(defined $compoundfile) {
+	
+	#replace the compound words in the definition
+	open(LST, "$compoundfile") or die ("Error: cannot open file $compoundfile for input.\n");
+	
+	# read the compound txt and put them in the hash array. 
+	while (my $line = <LST>)
+	{
+	    chomp($line);
+	    my $lower_case = lc($line);
+	    my @string = split('_', $lower_case);
+	    my $head = shift(@string);
+	    
+	    my $rest = join (' ', @string);
+	    push (@{$complist{$head}}, $rest);
+	}
+	close LST;
+	
+	# sort the compound txt 
+	foreach my $h (sort (keys (%complist)) )
+	{
+	    my @sort_list = sort(@{$complist{$h}});
+	    for my $i (0..$#sort_list)
+	    {
+		$complist{$h}[$i] = $sort_list[$i];
+	    }
+	}
+	
     }
-    close LST;
-
-    # sort the compound txt 
-    foreach my $h (sort (keys (%complist)) )
-    {
-        my @sort_list = sort(@{$complist{$h}});
-        for my $i (0..$#sort_list)
-        {
-            $complist{$h}[$i] = $sort_list[$i];
-        }
-    }
-
-    }
-
+    
     return $self;
 }
 
@@ -245,7 +245,12 @@ sub getRelatedness
 		$i++;
 		}
 		$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-		$def1 .= $5 . " " . "definitionstop" . " "; 
+		#$def1 .= $5 . " " . "definitionstop" . " "; 
+		my $temp = $5; 
+		if(defined $temp) { 
+		    $def1 .= $temp . " " . "definitionstop" . " "; 
+		}
+		
 		}
 
 		#if the definition is empty, return -1;
@@ -267,13 +272,16 @@ sub getRelatedness
 		$i++;
 		}
 		$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-		$def2 .= $5 . " " . "definitionstop" . " "; 
+		#$def2 .= $5 . " " . "definitionstop" . " "; 
+		my $temp = $5; 
+		if(defined $temp) { 
+		    $def2 .= $temp . " " . "definitionstop" . " "; 
+		}
 		}
-
 		#if the definition is empty, return -1;
 		if($def2 eq "")
 		{
-			return -1;
+		    return -1;
 		}
 	}	
 	} # end of WITHOUT --dictfile option 
@@ -366,7 +374,11 @@ sub getRelatedness
 		$i++;
 	    }
 	    $def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-	    $def1 .= $5 . " " . "definitionstop" . " "; 
+	    #$def1 .= $5 . " " . "definitionstop" . " ";
+	    my $temp = $5; 
+	    if(defined $temp) { 
+		$def1 .= $temp . " " . "definitionstop" . " "; 
+	    }
 	}
 	if(defined $term1_def)
 	{
@@ -395,7 +407,11 @@ sub getRelatedness
 		$j++;
 	    }
 	    $def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-	    $def2 .= $5 . " " . "definitionstop" . " "; 
+	    #$def2 .= $5 . " " . "definitionstop" . " "; 
+	    my $temp = $5; 
+	    if(defined $temp) { 
+		$def2 .= $temp . " " . "definitionstop" . " "; 
+	    }
 	}
 	if(defined $term2_def)
 	{
