@@ -309,7 +309,10 @@ sub getRelatedness
 		    $i++;
 		}
 		$def=~/(C[0-9]+) ([A-Za-z]+) ([A-Za-z0-9]+) ([A-Za-z0-9\.]+) \s*\:\s*(.*?)$/;
-		$d1 .= $5 . " ";
+		my $temp = $5; 
+		if(defined $temp) { 
+		    $d1 .= $temp . " ";
+		}
 	    }
 
 	    #if the definition is empty, return -1
