@@ -279,7 +279,7 @@ my $cuilist = $umls->getCuiList();
 
 if(defined $opt_metamap) { 
     
-    if(! ($opt_metamay=~/[0-9][0-9]/) ) {
+    if(! ($opt_metamap=~/[0-9][0-9]/) ) {
 	print STDERR "The --metamap option requires a two digit year.\n";
 	&minimalUsageNotes();
 	exit;
@@ -645,7 +645,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: create-icfrequency.pl,v 1.16 2011/05/04 18:39:25 btmcinnes Exp $';
+    print '$Id: create-icfrequency.pl,v 1.17 2015/10/04 14:35:59 btmcinnes Exp $';
     print "\nCopyright (c) 2008-2011, Ted Pedersen & Bridget McInnes\n";
 }
 
